Module consts Copy item path Source BUS The seed of the bus account PDA. BUS_ADDRESSES The addresses of the bus accounts. BUS_COUNT The number of bus accounts, for parallelizing mine operations. BUS_EPOCH_REWARDS The quantity of SPAM each bus is allowed to issue per epoch. EPOCH_DURATION The duration of an epoch, in units of seconds. INITIAL_DIFFICULTY The mining difficulty to initialize the program with. INITIAL_REWARD_RATE The reward rate to intialize the program with. MAX_EPOCH_REWARDS The maximum quantity of SPAM that can be mined per epoch, in units of nanoSPAM. MINT The seed of the mint account PDA. MINT_ADDRESS The address of the mint account. MINT_NOISE Noise for deriving the mint PDA. ONE_SPAM One SPAM token, denominated in units of nanoSPAM. PROOF The seed of proof account PDAs. SMOOTHING_FACTOR The smoothing factor for reward rate changes. The reward rate cannot change by more or less
than a factor of this constant from one epoch to the next. START_AT The unix timestamp after which mining can begin. TARGET_EPOCH_REWARDS The target quantity of SPAM to be mined per epoch, in units of nanoSPAM.
Inflation rate ≈ 1 SPAM / epoch (min 0, max 2) TOKEN_DECIMALS The decimal precision of the SPAM token.
Using SI prefixes, the smallest indivisible unit of SPAM is a nanoSPAM.
1 nanoSPAM = 0.000000001 SPAM = one billionth of an SPAM TREASURY The seed of the treasury account PDA. TREASURY_ADDRESS The address of the treasury account.